# pyrustats package
A package about statistics made by Ruukha
Currently it can only do Gaussian and Binomial distributions

# Files
Generaldistribution.py creates the 'Distribution' class for the distribution types to inherit
Gaussiandistribution.py creates the 'Gaussian' class
Binomialdistribution.py creates the 'Binomial' class
Both Gaussian and Binomial class files create functions to calculate the mean, standard deviation, probability density function (pdf), histogram, and a function to plot the normalized histogram of the data and a plot of the pdf along the same range

# Installation
No special requirements other than matplotlib